ClientBuilder

Struct ClientBuilder 

pub struct ClientBuilder { /* private fields */ }
Builder for Client struct.

Implementations

Source

impl ClientBuilder

pub fn new(target: impl Into<String>) -> Self

Create a new client builder with the given target server IP address.

pub fn port(self, port: u16) -> Self

Target port on server (1-65535)

pub fn data(self, data: Option<impl Into<String>>) -> Self

Target size of data to be uploaded/downloaded in the speed test including units (eg, 10MB, 1GB, 2GB). Instead of time.

pub fn time(self, time: u64) -> Self

Time limit per test direction in seconds (1-3600).

pub fn chunk_size(self, chunk_size: impl Into<String>) -> Result<Self>

Buffer size for read/write operations (eg, 32KiB, 64KiB, 128KiB).

pub fn ping_count(self, ping_count: u32) -> Self

Number of pings to perform for ping test (1-1000)

pub fn return_json(self, return_json: bool) -> Self

Return results as json

pub fn timeout(self, timeout: u64) -> Self

Connection timeout in seconds

pub fn retries(self, retries: u32) -> Self

Number of retry attempts on initial connection failure

pub fn quiet(self, quiet: bool) -> Self

Suppress progress output (results & errors only)

pub fn verbose(self, verbose: bool) -> Self

Enable verbose output

pub fn build(self) -> Result<Client>

Complete build of Client.