pub struct ClientBuilder { /* private fields */ }Expand description
Builder for Client struct.
Implementations
Sourceimpl ClientBuilder
impl ClientBuilder
Sourcepub fn new(target: impl Into<String>) -> Self
pub fn new(target: impl Into<String>) -> Self
Create a new client builder with the given target server IP address.
Sourcepub fn data(self, data: Option<impl Into<String>>) -> Self
pub fn data(self, data: Option<impl Into<String>>) -> Self
Target size of data to be uploaded/downloaded in the speed test including units (eg, 10MB, 1GB, 2GB). Instead of time.
Sourcepub fn chunk_size(self, chunk_size: impl Into<String>) -> Result<Self>
pub fn chunk_size(self, chunk_size: impl Into<String>) -> Result<Self>
Buffer size for read/write operations (eg, 32KiB, 64KiB, 128KiB).
Sourcepub fn ping_count(self, ping_count: u32) -> Self
pub fn ping_count(self, ping_count: u32) -> Self
Number of pings to perform for ping test (1-1000)
Sourcepub fn return_json(self, return_json: bool) -> Self
pub fn return_json(self, return_json: bool) -> Self
Return results as json